

########             ########
########             ########
########   FIGURES   ########
########             ########
########             ########


# all figures outputs from R were edited in Adobe Illustrator.
# examples were prepared by R.F, V.K then adjusted it for the rest of the figures


### -----------------------------------------------
### - Fig. 1 --- Nest predation in shorebirds - six maps
### -----------------------------------------------


rm( list = ls() )

library(dplyr) # for "glimpse"
library(sp)
library(gstat)
library(ggplot2)
library( scales ) # for "comma"
library( magrittr )
library( kriging )
library( lattice )
library( alphahull)
library( blighty )
library( raster)
library( spatstat )
library( maptools )
library( tmap )
library( mgcv )
library( rgeos )
library( Cairo )
library( rworldmap )
library( cleangeo )
library( maps )
library(RColorBrewer)



# from: https://stackoverflow.com/questions/9314658/colorbar-from-custom-colorramppalette
color.bar <- function(lut, min, max=-min, nticks=11, ticks=seq(min, max, len=nticks), title='', cairo = "") {
  scale = (length(lut))/(max-min)
  
  if( cairo != "" ) {
    pdf(cairo, width=2, height=5, pointsize = 18)
    plot(c(0,10), c(min,max), type='n', bty='n', xaxt='n', xlab='', yaxt='n', ylab='', main=title)
    axis(2, ticks, las=1)
    for (i in 1:(length(lut))) {
      y = (i-1)/scale + min
      rect(0,y,10,y+1/scale, col=lut[i], border=NA)
    }	
    dev.off()
  }
  
}






mypalette <- brewer.pal(11, "Reds")

preddata <- read.csv("Before+After2000_final.csv", sep=";")

sPDF <- getMap()
sPDF <- clgeo_Clean(sPDF)  ## Needed to fix up some non-closed polygons 

continents <-  levels(sPDF$continent)
idx <- which(continents == "Antarctica")
continents <- continents[-idx]

cont <-    sapply(continents,
                  FUN = function(i) {
                    ## Merge polygons within a continent
                    poly <- gUnionCascaded(subset(sPDF, continent==i))
                    ## Give each polygon a unique ID
                    poly <- spChFIDs(poly, i)
                    ## Make SPDF from SpatialPolygons object
                    SpatialPolygonsDataFrame(poly,
                                             data.frame(continent=i, row.names=i))
                  },
                  USE.NAMES=TRUE)

## Bind the 6 continent-level SPDFs into a single SPDF
cont <- Reduce(spRbind, cont)
data( gridExData )
bb <- matrix(c(-179.75, 200, -89.75, 89.75), nrow = 2, byrow =2 )
rownames(bb) <- c("s1", "s2")
colnames(bb) <- c("min", "max")
np <- SpatialPoints( coordinates( gridExData) , bbox = bb )

ngrid <- points2grid( np )


# ----- Analysis of daily nest predation (DPR) patterns ---------- 

# HISTORIC DATA - Before 2000
idx <- which( preddata$Period == "Before 2000" )
model2 <- gam( log( DPR_orig + 0.01)/log(10) ~ s(Latitude, Longitude, k = 50) , data = preddata[idx,] )
ndat <- data.frame( Longitude = coordinates( gridExData)[,1], Latitude = coordinates( gridExData )[,2]  )
pred2 <- predict( model2, ndat)


data.pred2 <- SpatialGridDataFrame( grid = ngrid, data.frame( pred = as.vector( pred2)) )


r <- raster(data.pred2)
spe <- gBuffer( cont, byid = TRUE, width = 0)
r.m <- mask( r, spe )

mypalette <- brewer.pal(9, "Reds")
quartz()
map(resolution = 0, col = "grey", bg = "lightcyan2", ylim = c(-65,90), xlim = c(-180, 177) )
image( r.m, col = mypalette, add = TRUE, zlim = c(-1.8, -1)  )

lon <- preddata[idx,]$Longitude
lat <- preddata[idx,]$Latitude
points( lon, lat, cex = 0.5, pch = 19)






pdf("DPRPredictedBefore2000.pdf", 5, 4 )
map(resolution = 0, col = "black", bg = "lightcyan2", ylim = c(-60,90), cex = 0.2, xlim = c(-180, 177) )
image( r.m, col = mypalette, add = TRUE, zlim = c(-1.8, -1) )
points( preddata[idx,]$Longitude, preddata[idx,]$Latitude, cex = 0.5, pch = 19)
dev.off()

color.bar(mypalette, min = -1.8, max = -1, nticks = 5, cairo = "DPRPredictedBefore2000bar.pdf" )




# RECENT DATA - After 2000
idx <- which( preddata$Period == "After 2000" )
model3 <- gam( log( DPR_orig + 0.01)/log(10) ~ s(Latitude, Longitude, k = 50) , data = preddata[idx,] )
ndat <- data.frame( Longitude = coordinates( gridExData)[,1], Latitude = coordinates( gridExData )[,2] )
pred3 <- predict( model3, ndat)
data.pred3 <- SpatialGridDataFrame( grid = ngrid, data.frame( pred = as.vector( pred3)))

r <- raster(data.pred3)
spe <- gBuffer( cont, byid = TRUE, width = 0)
r.m <- mask( r, spe )

mypalette <- brewer.pal(9, "Reds")
quartz()
map(resolution = 0, col = "grey", bg = "lightcyan2", ylim = c(-60,90) , xlim = c(-180, 177)  )
image(r.m, col = mypalette,  add = TRUE, zlim = c(-1.8, -0.95) )
points( preddata[idx,]$Longitude, preddata[idx,]$Latitude, cex = 0.5, pch = 19)

pdf("DPRPredictedAfter2000.pdf", 5, 4)
map(resolution = 0, col = "black", bg = "lightcyan2", ylim = c(-60,90), cex = 0.2, xlim = c(-180, 177) )
image(r.m, col = mypalette,  add = TRUE, zlim = c(-1.8, -0.95) )
points( preddata[idx,]$Longitude, preddata[idx,]$Latitude, cex = 0.5, pch = 19)
dev.off()

color.bar(mypalette, min = -1.8, max = -1, nticks = 5, cairo = "DPRPredictedAfter2000bar.pdf" )





# CHANGE - Difference between the periods

diffPred <- pred3 - pred2
data.pred4 <- SpatialGridDataFrame( grid = ngrid,  data.frame( pred = as.vector(  -1 * diffPred)) )

r <- raster(data.pred4)
spe <- gBuffer( cont, byid = TRUE, width = 0)
r.m <- mask( r, spe )

mypalette <- brewer.pal(11, "RdBu")
quartz()
map(resolution = 0, col = "grey", bg = "lightcyan2", ylim = c(-60,90), xlim = c(-180, 177) )
image(r.m, col = mypalette, ylim = c(2.8, 6), add = TRUE  )

pdf("DPRPredictedDifference.pdf", 5, 4)
map(resolution = 0, col = "black", bg = "lightcyan2", ylim = c(-60,90), cex = 0.2, xlim = c(-180, 177) )
image(r.m, col = mypalette, ylim = c(2.8, 6), zlim = c(-1, 1), add = TRUE )
dev.off()
color.bar(mypalette[11:1], min = -1, max = 1, nticks = 5, cairo = "DPRPredictedDifferencebar.pdf" )


# ----- Analysis of total nest predation (TPR) patterns ---------- 

# HISTORIC DATA - Before 2000
idx <- which( preddata$Period == "Before 2000" )
model2 <- gam( TPR_orig  ~ s(Latitude, Longitude, k = 50) , data = preddata[idx,] )
ndat <- data.frame( Longitude = coordinates( gridExData)[,1], Latitude = coordinates( gridExData )[,2]  )
pred2 <- predict( model2, ndat)
data.pred2 <- SpatialGridDataFrame( grid = ngrid, data.frame( pred = as.vector(  pred2)) )


r <- raster(data.pred2)
spe <- gBuffer( cont, byid = TRUE, width = 0)
r.m <- mask( r, spe )

mypalette <- brewer.pal(9, "Reds")
quartz()
map(resolution = 0, col = "grey", bg = "lightcyan2", ylim = c(-60,90) , xlim = c(-180, 177) )
image( r.m, col = mypalette, add = TRUE , zlim = c(15, 91) )
points( preddata[idx,]$Longitude, preddata[idx,]$Latitude, cex = 0.5, pch = 19)


pdf("TPRPredictedBefore2000.pdf", 5, 4 )
map(resolution = 0, col = "black", bg = "lightcyan2", ylim = c(-60,90), cex = 0.2 , xlim = c(-180, 177) )
image( r.m, col = mypalette, add = TRUE , zlim = c(15, 91) )
points( preddata[idx,]$Longitude, preddata[idx,]$Latitude, cex = 0.5, pch = 19)
dev.off()

color.bar(mypalette, min = 10, max = 90, nticks = 5, cairo = "TPRPredictedBefore2000bar.pdf" )




# RECENT DATA - After 2000
idx <- which( preddata$Period == "After 2000" )
model3 <- gam( TPR_orig + 0.005 ~ s(Latitude, Longitude, k = 50) , data = preddata[idx,] )
ndat <- data.frame( Longitude = coordinates( gridExData)[,1], Latitude = coordinates( gridExData )[,2] )
pred3 <- predict( model3, ndat)
data.pred3 <- SpatialGridDataFrame( grid = ngrid, data.frame( pred = as.vector( pred3)))

r <- raster(data.pred3)
spe <- gBuffer( cont, byid = TRUE, width = 0)
r.m <- mask( r, spe )

mypalette <- brewer.pal(9, "Reds")
quartz()
map(resolution = 0, col = "grey", bg = "lightcyan2", ylim = c(-60,90), xlim = c(-180, 177)  )
image(r.m, col = mypalette,  add = TRUE, zlim = c(15, 91))
points( preddata[idx,]$Longitude, preddata[idx,]$Latitude, cex = 0.5, pch = 19)

pdf("TPRPredictedAfter2000.pdf", 5, 4)
map(resolution = 0, col = "black", bg = "lightcyan2", ylim = c(-60,90), cex = 0.2, xlim = c(-180, 177) )
image(r.m, col = mypalette,  add = TRUE , zlim = c(15,91))
points( preddata[idx,]$Longitude, preddata[idx,]$Latitude, cex = 0.5, pch = 19)
dev.off()
color.bar(mypalette, min = 10, max = 90, nticks = 5, cairo = "TPRPredictedAfter2000bar.pdf" )




# CHANGE - Difference between the periods

diffPred <- pred3 - pred2
data.pred4 <- SpatialGridDataFrame( grid = ngrid,  data.frame( pred = as.vector( -1* diffPred)) )

r <- raster(data.pred4)
spe <- gBuffer( cont, byid = TRUE, width = 0)
r.m <- mask( r, spe )

mypalette <- brewer.pal(11, "RdBu")
quartz()
map(resolution = 0, col = "grey", bg = "lightcyan2", ylim = c(-60,90), xlim = c(-180, 177)  )
image(r.m, col = mypalette, ylim = c(2.8, 6), add = TRUE )

pdf("TPRPredictedDifference.pdf", 5, 4)
map(resolution = 0, col = "black", bg = "lightcyan2", ylim = c(-60,90), cex = 0.2, xlim = c(-180, 177) )
image(r.m, col = mypalette, ylim = c(2.8, 6), zlim = c(-70, 70) , add = TRUE)
dev.off()
color.bar(mypalette[11:1], min = -70, max = 70, nticks = 5, cairo = "TPRPredictedDifferencebar.pdf" )




### -----------------------------------------------
### - Fig. 2 --- Temporal changes in nest predation of shorebirds - six graphs
### -----------------------------------------------


###
### Fig. 2A - temporal trend in daily predation rate
### 



preddata <- read.csv("DATApopulations.csv", sep=";")


model1 <- gam(  DPR_orig  ~ s(mean_year, k = 5, by = Belt) , data = preddata)

idx2 <- which( preddata$Belt == "South temperate" )
model2 <- gam( DPR_orig   ~ s(mean_year, k = 5) , data = preddata[idx2,], method = "REML" )
min2 <- min(preddata[idx2,]$mean_year)
max2 <- max(preddata[idx2,]$mean_year)

idx3 <- which( preddata$Belt == "South tropics" )
model3 <- gam( DPR_orig  ~ s(mean_year, k = 5) , data = preddata[idx3,], method = "REML" )
min3 <- min(preddata[idx3,]$mean_year)
max3 <- max(preddata[idx3,]$mean_year)

idx4 <- which( preddata$Belt == "North tropics" )
model4 <- gam( DPR_orig   ~ s(mean_year, k = 5) , data = preddata[idx4,], method = "REML" )
min4 <- min(preddata[idx4,]$mean_year)
max4 <- max(preddata[idx4,]$mean_year)

idx5 <- which( preddata$Belt == "North temperate" )
model5 <- gam( DPR_orig   ~ s(mean_year, k = 5) , data = preddata[idx5,], method = "REML" )
min5 <- min(preddata[idx5,]$mean_year)
max5 <- max(preddata[idx5,]$mean_year)

idx6 <- which( preddata$Belt == "Arctic" )
model6 <- gam( DPR_orig ~ s(mean_year, k = 5) , data = preddata[idx6,], method = "REML" )
min6 <- min(preddata[idx6,]$mean_year)
max6 <- max(preddata[idx6,]$mean_year)

plat <- data.frame( mean_year = seq(1944, 2016, by = 1)  )

p2  <- predict( model2, plat, se = TRUE )
idx <- which( plat < min2 | plat >max2  )
p2$fit[idx] <- NA
p2$se.fit[idx] <- NA

p3  <- predict( model3, plat, se = TRUE )
idx <- which( plat < min3 | plat >max3  )
p3$fit[idx] <- NA
p3$se.fit[idx] <- NA

p4  <- predict( model4, plat, se = TRUE )
idx <- which( plat < min4 | plat >max4  )
p4$fit[idx] <- NA
p4$se.fit[idx] <- NA

p5  <- predict( model5, plat, se = TRUE )
idx <- which( plat < min5 | plat >max5  )
p5$fit[idx] <- NA
p5$se.fit[idx] <- NA

p6  <- predict( model6, plat, se = TRUE )
idx <- which( plat < min6 | plat >max6  )
p6$fit[idx] <- NA
p6$se.fit[idx] <- NA


plat$p2pred <- p2$fit
plat$p2se <- p2$se.fit
plat$p2min <- p2$fit - p2$se.fit
idx <- which( plat$p2min < 0)
plat$p2min[idx] <- 0
plat$p2max <- p2$fit + p2$se.fit

plat$p3pred <- p3$fit
plat$p3se <- p3$se.fit
plat$p3min <- p3$fit - p3$se.fit
idx <- which( plat$p3min < 0)
plat$p3min[idx] <- 0
plat$p3max <- p3$fit + p3$se.fit

plat$p4pred <- p4$fit
plat$p4se <- p4$se.fit
plat$p4min <- p4$fit - p4$se.fit
idx <- which( plat$p4min < 0)
plat$p4min[idx] <- 0
plat$p4max <- p4$fit + p4$se.fit

plat$p5pred <- p5$fit
plat$p5se <- p5$se.fit
plat$p5min <- p5$fit - p5$se.fit
idx <- which( plat$p5min < 0)
plat$p5min[idx] <- 0
plat$p5max <- p5$fit + p5$se.fit

plat$p6pred <- p6$fit
plat$p6se <- p6$se.fit
plat$p6min <- p6$fit - p6$se.fit
idx <- which( plat$p6min < 0)
plat$p6min[idx] <- 0
plat$p6max <- p6$fit + p6$se.fit


plotnew5 <- ggplot(data = plat, 
                   aes( x = mean_year, y = p2pred ))  + 
  geom_line(aes( y = p2pred ), size = 1.5, col = "lightseagreen") +
  geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "paleturquoise1", alpha = 0.5, linetype = "solid" ) + 
  aes( x = mean_year, y = p3pred )  + 
  geom_line(aes( y = p3pred ), size = 1.5, col = "dimgray") +
  geom_ribbon( aes(ymin =  p3min , ymax = p3max ), fill = "gainsboro", alpha = 0.5, linetype = "solid" ) +
  aes( x = mean_year, y = p4pred )  + 
  geom_line(aes( y = p4pred ), size = 1.5, col = "brown") +
  geom_ribbon( aes(ymin =  p4min , ymax = p4max ), fill = "navajowhite2", alpha = 0.5, linetype = "solid" ) +
  aes( x = mean_year, y = p5pred )  + 
  geom_line(aes( y = p5pred ), size = 1.5, col = "darkolivegreen") +
  geom_ribbon( aes(ymin =  p5min , ymax = p5max ), fill = "darkolivegreen3", alpha = 0.5, linetype = "solid" ) + 
  aes( x = mean_year, y = p6pred )  + 
  geom_line(aes( y = p6pred ), size = 1.5, col = "deeppink3") +
  geom_ribbon( aes(ymin =  p6min , ymax = p6max ), fill = "lightpink", alpha = 0.5, linetype = "solid" ) + 
  labs(x="Year",y="Daily nest predation") +
  ylim( 0, 0.07) +             
  scale_x_continuous(breaks = c(1944,1960,1980,2000,2016), labels = c(1944,1960,1980,2000,2016),) +
  scale_y_continuous(breaks = c(0,0.01,0.02,0.03,0.04,0.05,0.06,0.07), labels = c(0,0.01,0.02,0.03,0.04,0.05,0.06,0.07),) +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         legend.position="left",
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.text.x = element_text(size = 16),
         axis.text.y = element_text(size = 16),
         axis.title.x=element_text(size = 16),
         axis.title.y=element_text(size = 16) )
           
           
plotnew5
         
         
         
         
         ###
         ### Fig. 2B - temporal trend in total predation rate
         ### 
         
         
         
         preddata <- read.csv("DATApopulations.csv", sep=";")
         
         
         model1 <- gam(  TPR_perc  ~ s(mean_year, k = 5, by = Belt) , data = preddata)
         
         idx2 <- which( preddata$Belt == "South temperate" )
         model2 <- gam( TPR_perc   ~ s(mean_year, k = 5) , data = preddata[idx2,], method = "REML" )
         min2 <- min(preddata[idx2,]$mean_year)
         max2 <- max(preddata[idx2,]$mean_year)
         
         idx3 <- which( preddata$Belt == "South tropics" )
         model3 <- gam( TPR_perc  ~ s(mean_year, k = 5) , data = preddata[idx3,], method = "REML" )
         min3 <- min(preddata[idx3,]$mean_year)
         max3 <- max(preddata[idx3,]$mean_year)
         
         idx4 <- which( preddata$Belt == "North tropics" )
         model4 <- gam( TPR_perc   ~ s(mean_year, k = 5) , data = preddata[idx4,], method = "REML" )
         min4 <- min(preddata[idx4,]$mean_year)
         max4 <- max(preddata[idx4,]$mean_year)
         
         idx5 <- which( preddata$Belt == "North temperate" )
         model5 <- gam( TPR_perc   ~ s(mean_year, k = 5) , data = preddata[idx5,], method = "REML" )
         min5 <- min(preddata[idx5,]$mean_year)
         max5 <- max(preddata[idx5,]$mean_year)
         
         idx6 <- which( preddata$Belt == "Arctic" )
         model6 <- gam( TPR_perc ~ s(mean_year, k = 5) , data = preddata[idx6,], method = "REML" )
         min6 <- min(preddata[idx6,]$mean_year)
         max6 <- max(preddata[idx6,]$mean_year)
         
         plat <- data.frame( mean_year = seq(1944, 2016, by = 1)  )
         
         p2  <- predict( model2, plat, se = TRUE )
         idx <- which( plat < min2 | plat >max2  )
         p2$fit[idx] <- NA
         p2$se.fit[idx] <- NA
         
         p3  <- predict( model3, plat, se = TRUE )
         idx <- which( plat < min3 | plat >max3  )
         p3$fit[idx] <- NA
         p3$se.fit[idx] <- NA
         
         p4  <- predict( model4, plat, se = TRUE )
         idx <- which( plat < min4 | plat >max4  )
         p4$fit[idx] <- NA
         p4$se.fit[idx] <- NA
         
         p5  <- predict( model5, plat, se = TRUE )
         idx <- which( plat < min5 | plat >max5  )
         p5$fit[idx] <- NA
         p5$se.fit[idx] <- NA
         
         p6  <- predict( model6, plat, se = TRUE )
         idx <- which( plat < min6 | plat >max6  )
         p6$fit[idx] <- NA
         p6$se.fit[idx] <- NA
         
         
         plat$p2pred <- p2$fit
         plat$p2se <- p2$se.fit
         plat$p2min <- p2$fit - p2$se.fit
         idx <- which( plat$p2min < 0)
         plat$p2min[idx] <- 0
         plat$p2max <- p2$fit + p2$se.fit
         
         plat$p3pred <- p3$fit
         plat$p3se <- p3$se.fit
         plat$p3min <- p3$fit - p3$se.fit
         idx <- which( plat$p3min < 0)
         plat$p3min[idx] <- 0
         plat$p3max <- p3$fit + p3$se.fit
         
         plat$p4pred <- p4$fit
         plat$p4se <- p4$se.fit
         plat$p4min <- p4$fit - p4$se.fit
         idx <- which( plat$p4min < 0)
         plat$p4min[idx] <- 0
         plat$p4max <- p4$fit + p4$se.fit
         
         plat$p5pred <- p5$fit
         plat$p5se <- p5$se.fit
         plat$p5min <- p5$fit - p5$se.fit
         idx <- which( plat$p5min < 0)
         plat$p5min[idx] <- 0
         plat$p5max <- p5$fit + p5$se.fit
         
         plat$p6pred <- p6$fit
         plat$p6se <- p6$se.fit
         plat$p6min <- p6$fit - p6$se.fit
         idx <- which( plat$p6min < 0)
         plat$p6min[idx] <- 0
         plat$p6max <- p6$fit + p6$se.fit
         
         plotnew5 <- ggplot(data = plat, 
                            aes( x = mean_year, y = p2pred ))  + 
           geom_line(aes( y = p2pred ), size = 1.5, col = "lightseagreen") +
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "paleturquoise1", alpha = 0.5, linetype = "solid" ) + 
           
           aes( x = mean_year, y = p3pred )  + 
           geom_line(aes( y = p3pred ), size = 1.5, col = "dimgray") +
           geom_ribbon( aes(ymin =  p3min , ymax = p3max ), fill = "gainsboro", alpha = 0.5, linetype = "solid" ) +
           aes( x = mean_year, y = p4pred )  + 
           geom_line(aes( y = p4pred ), size = 1.5, col = "brown") +
           geom_ribbon( aes(ymin =  p4min , ymax = p4max ), fill = "navajowhite2", alpha = 0.5, linetype = "solid" ) +
           aes( x = mean_year, y = p5pred )  + 
           geom_line(aes( y = p5pred ), size = 1.5, col = "darkolivegreen") +
           geom_ribbon( aes(ymin =  p5min , ymax = p5max ), fill = "darkolivegreen3", alpha = 0.5, linetype = "solid" ) + 
           aes( x = mean_year, y = p6pred )  + 
           geom_line(aes( y = p6pred ), size = 1.5, col = "deeppink3") +
           geom_ribbon( aes(ymin =  p6min , ymax = p6max ), fill = "lightpink", alpha = 0.5, linetype = "solid" ) + 
           labs(x="Year",y="Total nest predation (%)") +
           ylim( 0, 80) +
           scale_x_continuous(breaks = c(1944,1960,1980,2000,2016), labels = c(1944,1960,1980,2000,2016),) +
           theme_bw() + 
           theme( panel.border = element_blank(), 
                  panel.grid.major = element_blank(),
                  panel.grid.minor = element_blank(), 
                  legend.position="none",
                  axis.line = element_line(colour = 'black', size = 0.25),
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  axis.text.x = element_text(size = 16),
                  axis.text.y = element_text(size = 16),
                  axis.title.x=element_text(size = 16),
                  axis.title.y=element_text(size = 16) ) 
         
         
         
         plotnew5
         
         
         
         ###
         ### Fig. 2C - temporal trend in daily predation rate (two clades)
         ### 

         preddata <- read.csv("DATApopulations.csv", sep=";")
         
         
         model1 <- gam(  DPR_orig  ~ s(mean_year, k = 5, by = clade) , data = preddata)
         
         idx2 <- which( preddata$clade == "Charadrii" )
         model2 <- gam( DPR_orig   ~ s(mean_year, k = 5) , data = preddata[idx2,], method = "REML" )
         min2 <- min(preddata[idx2,]$mean_year)
         max2 <- max(preddata[idx2,]$mean_year)
         
         idx3 <- which( preddata$clade == "Scolopaci" )
         model3 <- gam( DPR_orig  ~ s(mean_year, k = 5) , data = preddata[idx3,], method = "REML" )
         min3 <- min(preddata[idx3,]$mean_year)
         max3 <- max(preddata[idx3,]$mean_year)
         
         plat <- data.frame( mean_year = seq(1944, 2016, by = 1)  )
         
         p2  <- predict( model2, plat, se = TRUE )
         idx <- which( plat < min2 | plat >max2  )
         p2$fit[idx] <- NA
         p2$se.fit[idx] <- NA
         
         p3  <- predict( model3, plat, se = TRUE )
         idx <- which( plat < min3 | plat >max3  )
         p3$fit[idx] <- NA
         p3$se.fit[idx] <- NA
         
         
         plat$p2pred <- p2$fit
         plat$p2se <- p2$se.fit
         plat$p2min <- p2$fit - p2$se.fit
         idx <- which( plat$p2min < 0)
         plat$p2min[idx] <- 0
         plat$p2max <- p2$fit + p2$se.fit
         
         plat$p3pred <- p3$fit
         plat$p3se <- p3$se.fit
         plat$p3min <- p3$fit - p3$se.fit
         idx <- which( plat$p3min < 0)
         plat$p3min[idx] <- 0
         plat$p3max <- p3$fit + p3$se.fit
         
         
         plotnew5 <- ggplot(data = plat, 
                            aes( x = mean_year, y = p2pred ))  + 
           geom_line(aes( y = p2pred ), size = 1.5, col = "darkgoldenrod") +
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "lightgoldenrod1", alpha = 0.5, linetype = "solid" ) + 
           aes( x = mean_year, y = p3pred )  + 
           geom_line(aes( y = p3pred ), size = 1.5, col = "darkorchid1") +
           geom_ribbon( aes(ymin =  p3min , ymax = p3max ), fill = "lavender", alpha = 0.5, linetype = "solid" ) +
           labs(x="Year",y="Daily nest predation") +
           scale_x_continuous(breaks = c(1944,1960,1980,2000,2016), labels = c(1944,1960,1980,2000,2016),) +
           scale_y_continuous(breaks = c(0,0.01,0.02,0.03,0.04,0.05,0.06,0.07), labels = c(0,0.01,0.02,0.03,0.04,0.05,0.06,0.07),) +
           theme_bw() + 
           theme( panel.border = element_blank(), 
                  panel.grid.major = element_blank(),
                  panel.grid.minor = element_blank(), 
                  legend.position="none",
                  axis.line = element_line(colour = 'black', size = 0.25),
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  axis.text.x = element_text(size = 16),
                  axis.text.y = element_text(size = 16),
                  axis.title.x=element_text(size = 16),
                  axis.title.y=element_text(size = 16) ) 		
         
         plotnew5
         
         
         
         ###
         ### Fig. 2D - temporal trend in total predation rate (two clades)
         ### 
         
         library(ggplot2)
         library(mgcv)
         
         preddata <- read.csv("DATApopulations.csv", sep=";")
         
         
         model1 <- gam(  TPR_perc  ~ s(mean_year, k = 5, by = clade) , data = preddata)
         
         idx2 <- which( preddata$clade == "Charadrii" )
         model2 <- gam( TPR_perc   ~ s(mean_year, k = 5) , data = preddata[idx2,], method = "REML" )
         min2 <- min(preddata[idx2,]$mean_year)
         max2 <- max(preddata[idx2,]$mean_year)
         
         idx3 <- which( preddata$clade == "Scolopaci" )
         model3 <- gam( TPR_perc  ~ s(mean_year, k = 5) , data = preddata[idx3,], method = "REML" )
         min3 <- min(preddata[idx3,]$mean_year)
         max3 <- max(preddata[idx3,]$mean_year)
         
         plat <- data.frame( mean_year = seq(1944, 2016, by = 1)  )
         
         p2  <- predict( model2, plat, se = TRUE )
         idx <- which( plat < min2 | plat >max2  )
         p2$fit[idx] <- NA
         p2$se.fit[idx] <- NA
         
         p3  <- predict( model3, plat, se = TRUE )
         idx <- which( plat < min3 | plat >max3  )
         p3$fit[idx] <- NA
         p3$se.fit[idx] <- NA
         
         
         plat$p2pred <- p2$fit
         plat$p2se <- p2$se.fit
         plat$p2min <- p2$fit - p2$se.fit
         idx <- which( plat$p2min < 0)
         plat$p2min[idx] <- 0
         plat$p2max <- p2$fit + p2$se.fit
         
         plat$p3pred <- p3$fit
         plat$p3se <- p3$se.fit
         plat$p3min <- p3$fit - p3$se.fit
         idx <- which( plat$p3min < 0)
         plat$p3min[idx] <- 0
         plat$p3max <- p3$fit + p3$se.fit
         
         
         plotnew5 <- ggplot(data = plat, 
                            aes( x = mean_year, y = p2pred ))  + 
           geom_line(aes( y = p2pred ), size = 1.5, col = "darkgoldenrod") +
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "lightgoldenrod1", alpha = 0.5, linetype = "solid" ) + 
           aes( x = mean_year, y = p3pred )  + 
           geom_line(aes( y = p3pred ), size = 1.5, col = "darkorchid1") +
           geom_ribbon( aes(ymin =  p3min , ymax = p3max ), fill = "lavender", alpha = 0.5, linetype = "solid" ) +
           ylim( 0, 80) +
           labs(x="Year",y="Total nest predation (%)") +
           scale_x_continuous(breaks = c(1944,1960,1980,2000,2016), labels = c(1944,1960,1980,2000,2016),) +
           theme_bw() + 
           theme( panel.border = element_blank(), 
                  panel.grid.major = element_blank(),
                  panel.grid.minor = element_blank(), 
                  legend.position="none",
                  axis.line = element_line(colour = 'black', size = 0.25),
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  axis.text.x = element_text(size = 16),
                  axis.text.y = element_text(size = 16),
                  axis.title.x=element_text(size = 16),
                  axis.title.y=element_text(size = 16) ) 		
         
         plotnew5
         
         
         # Figs 2E and 2F were prepared in Excel and adjusted accordingly journal guidelines in Adobe Illustrator.
         
         
         
         ### -----------------------------------------------
         ### - Fig 3 --- Latitudinal gradient in historic versus recent nest predation of shorebirds - two graphs
         ### -----------------------------------------------
         
         
         
         ###
         ### Fig. 3A - latitudinal gradient in daily predation rate
         ### 
         
  
         
         preddata <- read.csv("Before+After2000_final.csv", sep=";")
         
         
         model1 <- gam( DPR_orig ~ s(Latitude, k = 5, by = Period) , data = preddata )
         
         idx2 <- which( preddata$Period == "Before 2000" )
         model2 <- gam( DPR_orig  ~ s(Latitude, k = 5) , data = preddata[idx2,] )
         min2 <- min(preddata[idx2,]$Latitude)
         max2 <- max(preddata[idx2,]$Latitude)
         
         
         idx3 <- which( preddata$Period == "After 2000" )
         model3 <- gam( DPR_orig ~ s(Latitude, k = 5) , data = preddata[idx3,] )
         min3 <- min(preddata[idx3,]$Latitude)
         max3 <- max(preddata[idx3,]$Latitude)
         
         plat <- data.frame( Latitude = seq(-62, 80, by = 1)  )
         
         p2 <- predict( model2, plat, se = TRUE )
         idx <- which( plat < min2 | plat >max2  )
         p2$fit[idx] <- NA
         p2$se.fit[idx] <- NA
         
         p3  <- predict( model3, plat, se = TRUE )
         idx <- which( plat < min3 | plat >max3  )
         p3$fit[idx] <- NA
         p3$se.fit[idx] <- NA
         
         
         plat$p2pred <- p2$fit
         plat$p2se <- p2$se.fit
         plat$p2min <- p2$fit - p2$se.fit
         idx <- which( plat$p2min < 0)
         plat$p2min[idx] <- 0
         plat$p2max <- p2$fit + p2$se.fit
         
         plat$p3pred <- p3$fit
         plat$p3se <- p3$se.fit
         plat$p3min <- p3$fit - p3$se.fit
         idx <- which( plat$p3min < 0)
         plat$p3min[idx] <- 0
         plat$p3max <- p3$fit + p3$se.fit
         
         plotnew1 <- ggplot(data = plat, aes( x = Latitude, y = p2pred ))  + 
           geom_line(aes( y = p2pred ), size = 1.5, col = "blue") +
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "lightcyan2", alpha = 0.5, linetype = "solid" ) + 
           aes(  x = Latitude, y = p3pred ) + 
           geom_line(aes(y = p3pred), size = 1.5, col = "red" ) +
           geom_ribbon( aes( ymin = p3min, ymax = p3max),fill = "peachpuff2" , alpha = 0.3) + 
           labs(x="Latitude",y="Daily nest predation") +
           ylim( 0, 0.075) +
           scale_x_continuous(breaks = c(-90,-60,-30,0,30,60,80,90), labels = c(-90,-60,-30,0,30,60,80,90),) +
           theme_bw() + 
           theme( panel.border = element_blank(), 
                  panel.grid.major = element_blank(),
                  panel.grid.minor = element_blank(), 
                  legend.position="none",
                  axis.line = element_line(colour = 'black', size = 0.25),
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  axis.text.x = element_text(size = 16),
                  axis.text.y = element_text(size = 16),
                  axis.title.x=element_text(size = 16),
                  axis.title.y=element_text(size = 16) ) 		
         
         
         plotnew1
         
         
         
         
         ###
         ### Fig. 3B - latitudinal gradient in total predation rate
         ### 
         
         
         preddata <- read.csv("Before+After2000_final.csv", sep=";")
         
         
         model1 <- gam( TPR_orig ~ s(Latitude, k = 5, by = Period) , data = preddata )
         
         idx2 <- which( preddata$Period == "Before 2000" )
         model2 <- gam( TPR_orig  ~ s(Latitude, k = 5) , data = preddata[idx2,] )
         min2 <- min(preddata[idx2,]$Latitude)
         max2 <- max(preddata[idx2,]$Latitude)
         
         
         idx3 <- which( preddata$Period == "After 2000" )
         model3 <- gam( TPR_orig ~ s(Latitude, k = 5) , data = preddata[idx3,] )
         min3 <- min(preddata[idx3,]$Latitude)
         max3 <- max(preddata[idx3,]$Latitude)
         
         
         plat <- data.frame( Latitude = seq(-62, 80, by = 1)  )
         
         p2 <- predict( model2, plat, se = TRUE )
         idx <- which( plat < min2 | plat >max2  )
         p2$fit[idx] <- NA
         p2$se.fit[idx] <- NA
         
         p3  <- predict( model3, plat, se = TRUE )
         idx <- which( plat < min3 | plat >max3  )
         p3$fit[idx] <- NA
         p3$se.fit[idx] <- NA
         
         
         plat$p2pred <- p2$fit
         plat$p2se <- p2$se.fit
         plat$p2min <- p2$fit - p2$se.fit
         idx <- which( plat$p2min < 0)
         plat$p2min[idx] <- 0
         plat$p2max <- p2$fit + p2$se.fit
         
         plat$p3pred <- p3$fit
         plat$p3se <- p3$se.fit
         plat$p3min <- p3$fit - p3$se.fit
         idx <- which( plat$p3min < 0)
         plat$p3min[idx] <- 0
         plat$p3max <- p3$fit + p3$se.fit
         
         
         plotnew2 <- ggplot(data = plat, aes( x = Latitude, y = p2pred ))  + 
           geom_line(aes( y = p2pred ), size = 1.5, col = "blue") +
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "lightcyan2", alpha = 0.5, linetype = "solid" ) + 
           aes(  x = Latitude, y = p3pred ) + 
           geom_line(aes(y = p3pred), size = 1.5, col = "red" ) +
           geom_ribbon( aes( ymin = p3min, ymax = p3max),fill = "peachpuff2" , alpha = 0.3) +
           labs( y = "Total nest predation (%)") +
           ylim( 0, 80) +
           scale_x_continuous(breaks = c(-90,-60,-30,0,30,60,80,90), labels = c(-90,-60,-30,0,30,60,80,90),) +
           theme_bw() + 
           theme( panel.border = element_blank(), 
                  panel.grid.major = element_blank(),
                  panel.grid.minor = element_blank(), 
                  legend.position="none",
                  axis.line = element_line(colour = 'black', size = 0.25),
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  axis.text.x = element_text(size = 16),
                  axis.text.y = element_text(size = 16),
                  axis.title.x=element_text(size = 16),
                  axis.title.y=element_text(size = 16) ) 
         
         
         plotnew2 
         
         
         
         
         
         ### -----------------------------------------------
         ### - Fig. 4 --- Climate change predicts nest predation rates in shorebirds - four graphs
         ### -----------------------------------------------
         
         
         ###
         ### Fig- 4A - temperature slope 30 and daily predation rate 
         ###
         

         preddata <- read.csv("WN_withclima_complete_2018.csv", sep=",", h = T)
         
         model1 <- gam(  DPR_orig  ~ temp_slope_30, k = 5 , data = preddata)
         
         model2 <- gam( DPR_orig   ~ temp_slope_30, k = 5 , data = preddata, method = "REML" )
         
         min2 <- min(preddata$temp_slope_30)
         
         max2 <- max(preddata$temp_slope_30)

         plat <- data.frame( temp_slope_30 = seq(-0.05, 0.10, by = 0.01)  )
         
         p2  <- predict( model2, plat, se = TRUE )
         
         plat$p2pred <- p2$fit
         
         plat$p2se <- p2$se.fit
         
         plat$p2min <- p2$fit - p2$se.fit
         
         idx <- which( plat$p2min < 0)
         
         plat$p2min[idx] <- 0
         
         plat$p2max <- p2$fit + p2$se.fit
         
         
         
         
         plotnew5 <- ggplot(data = plat, 
                            
                            aes( x = temp_slope_30, y = p2pred ))  + 
           
           geom_line(aes( y = p2pred ), size = 1.5, col = "black") +
           
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "gray69", alpha = 0.5, linetype = "solid" ) + 
           
           ylim( 0, 0.06) +
           
           labs(x="Ambient temperature slope",y="Daily nest predation") +
           
           
           
           theme_bw() + 
           
           theme( panel.border = element_blank(), 
                  
                  panel.grid.major = element_blank(),
                  
                  panel.grid.minor = element_blank(), 
                  
                  legend.position="none",
                  
                  axis.line = element_line(colour = 'black', size = 0.25),
                  
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  
                  axis.text.x = element_text(size = 16),
                  
                  axis.text.y = element_text(size = 16),
                  
                  axis.title.x=element_text(size = 16),
                  
                  axis.title.y=element_text(size = 16) ) 		
         
         
         
         
         
         plotnew5
         
         
         
         
         
         ###
         ### Fig. 4B - temperature slope 30 and total predation rate 
         ###
         
        
         
         preddata <- read.csv("WN_withclima_complete_2018.csv", h = T)
         
         
         
         model1 <- gam(  TPR_orig  ~ temp_slope_30, k = 5 , data = preddata)
         
         
         
         model2 <- gam( TPR_orig   ~ temp_slope_30, k = 5 , data = preddata, method = "REML" )
         
         min2 <- min(preddata$temp_slope_30)
         
         max2 <- max(preddata$temp_slope_30)
         
         
         
         plat <- data.frame( temp_slope_30 = seq(-0.05, 0.10, by = 0.01)  )
         
         
         
         p2  <- predict( model2, plat, se = TRUE )
         
         
         
         
         
         
         
         plat$p2pred <- p2$fit
         
         
         plat$p2se <- p2$se.fit
         
         plat$p2min <- p2$fit - p2$se.fit
         
         idx <- which( plat$p2min < 0)
         
         plat$p2min[idx] <- 0
         
         plat$p2max <- p2$fit + p2$se.fit
         
         
         
         
         plotnew5 <- ggplot(data = plat, 
                            
                            aes( x = temp_slope_30, y = p2pred ))  + 
           
           geom_line(aes( y = p2pred ), size = 1.5, col = "black") +
           
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "gray69", alpha = 0.5, linetype = "solid" ) + 
           
           ylim( 0, 0.8) +
           
           labs(x="Ambient temperature slope",y="Total nest predation (%)") +
           
           
           
           theme_bw() + 
           
           theme( panel.border = element_blank(), 
                  
                  panel.grid.major = element_blank(),
                  
                  panel.grid.minor = element_blank(), 
                  
                  legend.position="none",
                  
                  axis.line = element_line(colour = 'black', size = 0.25),
                  
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  
                  axis.text.x = element_text(size = 16),
                  
                  axis.text.y = element_text(size = 16),
                  
                  axis.title.x=element_text(size = 16),
                  
                  axis.title.y=element_text(size = 16) ) 		
         
         
         
         
         
         plotnew5
         
  
         ###
         ### Fig. 4C - temperature sd 30 and daily predation rate 
         ###
         
         
         
         
         preddata <- read.csv("WN_withclima_complete_2018.csv", h = T)
         
         
         
         model1 <- gam(  DPR_orig  ~ temp_sd_30, k = 5 , data = preddata)
         
         
         
         model2 <- gam( DPR_orig   ~ temp_sd_30, k = 5 , data = preddata, method = "REML" )
         
         min2 <- min(preddata$temp_sd_30)
         
         max2 <- max(preddata$temp_sd_30)
         
         
         
         plat <- data.frame( temp_sd_30 = seq(0, 1.5, by = 0.1)  )
         
         
         
         p2  <- predict( model2, plat, se = TRUE )
         
         plat$p2pred <- p2$fit
         
         
         plat$p2se <- p2$se.fit
         
         plat$p2min <- p2$fit - p2$se.fit
         
         idx <- which( plat$p2min < 0)
         
         plat$p2min[idx] <- 0
         
         plat$p2max <- p2$fit + p2$se.fit
         
         
         
         
         plotnew5 <- ggplot(data = plat, 
                            
                            aes( x = temp_sd_30, y = p2pred ))  + 
           
           geom_line(aes( y = p2pred ), size = 1.5, col = "black") +
           
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "gray69", alpha = 0.5, linetype = "solid" ) + 
           
           ylim( 0, 0.06) +
           
           labs(x="Ambient temperature standard deviation",y="Daily nest predation") +
           
           theme_bw() + 
           
           theme( panel.border = element_blank(), 
                  
                  panel.grid.major = element_blank(),
                  
                  panel.grid.minor = element_blank(), 
                  
                  legend.position="none",
                  
                  axis.line = element_line(colour = 'black', size = 0.25),
                  
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  
                  axis.text.x = element_text(size = 16),
                  
                  axis.text.y = element_text(size = 16),
                  
                  axis.title.x=element_text(size = 16),
                  
                  axis.title.y=element_text(size = 16) ) 		
         
         
         
         
         
         plotnew5
         
         
         
         
         
         
         #####
         ##### Fig. 4D - temperature sd 30 and total predation rate 
         #####
         

         
         preddata <- read.csv("WN_withclima_complete_2018.csv", h = T)
         model1 <- gam(  TPR_orig  ~ temp_sd_30, k = 5 , data = preddata)

         model2 <- gam( TPR_orig   ~ temp_sd_30, k = 5 , data = preddata, method = "REML" )
         
         min2 <- min(preddata$temp_sd_30)
         
         max2 <- max(preddata$temp_sd_30)
     
         plat <- data.frame( temp_sd_30 = seq(0, 1.5, by = 0.01)  )
   
         p2  <- predict( model2, plat, se = TRUE )
  
         plat$p2pred <- p2$fit
         
         
         plat$p2se <- p2$se.fit
         
         plat$p2min <- p2$fit - p2$se.fit
         
         idx <- which( plat$p2min < 0)
         
         plat$p2min[idx] <- 0
         
         plat$p2max <- p2$fit + p2$se.fit
  
         plotnew5 <- ggplot(data = plat, 
                            
                            aes( x = temp_sd_30, y = p2pred ))  + 
           
           geom_line(aes( y = p2pred ), size = 1.5, col = "black") +
           
           geom_ribbon( aes(ymin =  p2min , ymax = p2max ), fill = "gray69", alpha = 0.5, linetype = "solid" ) + 
           
           ylim( 0, 0.8) +
           
           labs(x="Ambient temperature standard deviation",y="Total nest predation (%)") +
   
           theme_bw() + 
           
           theme( panel.border = element_blank(), 
                  
                  panel.grid.major = element_blank(),
                  
                  panel.grid.minor = element_blank(), 
                  
                  legend.position="none",
                  
                  axis.line = element_line(colour = 'black', size = 0.25),
                  
                  axis.ticks = element_line(colour = "black", size = 0.25),
                  
                  axis.text.x = element_text(size = 16),
                  
                  axis.text.y = element_text(size = 16),
                  
                  axis.title.x=element_text(size = 16),
                  
                  axis.title.y=element_text(size = 16) ) 		
    
         plotnew5
         
         
         
         
  
         